summaryrefslogtreecommitdiffstats
path: root/src/gvimagepart/gvimagepart.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gvimagepart/gvimagepart.cpp')
-rw-r--r--src/gvimagepart/gvimagepart.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/gvimagepart/gvimagepart.cpp b/src/gvimagepart/gvimagepart.cpp
index 68b75eb..f36796c 100644
--- a/src/gvimagepart/gvimagepart.cpp
+++ b/src/gvimagepart/gvimagepart.cpp
@@ -129,7 +129,7 @@ GVImagePart::~GVImagePart() {
void GVImagePart::partActivateEvent(KParts::PartActivateEvent* event) {
if (event->activated()) {
- KConfig* config=new KConfig("gwenviewrc");
+ TDEConfig* config=new TDEConfig("gwenviewrc");
Cache::instance()->readConfig(config,CONFIG_CACHE_GROUP);
delete config;
}
@@ -329,7 +329,7 @@ void GVImagePart::saveAs() {
}
-void GVImagePart::showJobError(KIO::Job* job) {
+void GVImagePart::showJobError(TDEIO::Job* job) {
if (job->error() != 0) {
job->showErrorDialog(widget());
}
@@ -348,11 +348,11 @@ void GVImagePart::saveOriginalAs() {
TQByteArray data = Cache::instance()->file(srcURL);
if (data.size() == 0) {
- // We need to read the image again. Let KIO::copy do the work.
- KIO::Job* job = KIO::copy(srcURL, dstURL);
+ // We need to read the image again. Let TDEIO::copy do the work.
+ TDEIO::Job* job = TDEIO::copy(srcURL, dstURL);
job->setWindow(widget());
- connect(job, TQT_SIGNAL(result(KIO::Job*)),
- this, TQT_SLOT(showJobError(KIO::Job*)) );
+ connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
+ this, TQT_SLOT(showJobError(TDEIO::Job*)) );
return;
}
@@ -386,14 +386,14 @@ DataUploader::DataUploader(TQWidget* dialogParent, const TQByteArray& data, cons
// Now upload it
KURL tmpURL;
tmpURL.setPath(mTempFile.name());
- KIO::Job* job = KIO::copy(tmpURL, dstURL);
+ TDEIO::Job* job = TDEIO::copy(tmpURL, dstURL);
job->setWindow(dialogParent);
- connect(job, TQT_SIGNAL(result(KIO::Job*)),
- this, TQT_SLOT(slotJobFinished(KIO::Job*)) );
+ connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
+ this, TQT_SLOT(slotJobFinished(TDEIO::Job*)) );
}
-void DataUploader::slotJobFinished(KIO::Job* job) {
+void DataUploader::slotJobFinished(TDEIO::Job* job) {
if (job->error() != 0) {
job->showErrorDialog(mDialogParent);
}